# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKIOGIPLPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkGiplImageIOPython
else:
    import _itkGiplImageIOPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKIOImageBaseBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython

def itkGiplImageIO_New():
    return itkGiplImageIO.New()

class itkGiplImageIO(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkGiplImageIO class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGiplImageIO_Pointer"""
        return _itkGiplImageIOPython.itkGiplImageIO___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGiplImageIO_Pointer"""
        return _itkGiplImageIOPython.itkGiplImageIO_Clone(self)

    def __init__(self):
        r"""__init__(self) -> itkGiplImageIO"""
        _itkGiplImageIOPython.itkGiplImageIO_swiginit(self, _itkGiplImageIOPython.new_itkGiplImageIO())

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkGiplImageIOPython.itkGiplImageIO_PrintSelf(self, os, indent)
    __swig_destroy__ = _itkGiplImageIOPython.delete_itkGiplImageIO

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGiplImageIO

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGiplImageIOPython.itkGiplImageIO_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGiplImageIO

        Create a new object of the class itkGiplImageIO and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGiplImageIO.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGiplImageIO.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGiplImageIO.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGiplImageIO in _itkGiplImageIOPython:
_itkGiplImageIOPython.itkGiplImageIO_swigregister(itkGiplImageIO)

def itkGiplImageIOFactory_New():
    return itkGiplImageIOFactory.New()

class itkGiplImageIOFactory(itk.ITKCommonBasePython.itkObjectFactoryBase):
    r"""Proxy of C++ itkGiplImageIOFactory class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGiplImageIOFactory_Pointer"""
        return _itkGiplImageIOPython.itkGiplImageIOFactory___New_orig__()

    @staticmethod
    def RegisterOneFactory():
        r"""RegisterOneFactory()"""
        return _itkGiplImageIOPython.itkGiplImageIOFactory_RegisterOneFactory()
    __swig_destroy__ = _itkGiplImageIOPython.delete_itkGiplImageIOFactory

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGiplImageIOFactory

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGiplImageIOPython.itkGiplImageIOFactory_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGiplImageIOFactory

        Create a new object of the class itkGiplImageIOFactory and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGiplImageIOFactory.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGiplImageIOFactory.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGiplImageIOFactory.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGiplImageIOFactory in _itkGiplImageIOPython:
_itkGiplImageIOPython.itkGiplImageIOFactory_swigregister(itkGiplImageIOFactory)

